@@ -2,14 +2,9 @@ use strict;
 use warnings;
 
 package B::Compiling;
-BEGIN {
-  $B::Compiling::AUTHORITY = 'cpan:FLORA';
-}
-{
-  $B::Compiling::VERSION = '0.04';
-}
+our $AUTHORITY = 'cpan:FLORA';
 # ABSTRACT: Expose PL_compiling to perl
-
+$B::Compiling::VERSION = '0.05';
 use B;
 use XSLoader;
 
@@ -29,7 +24,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -65,7 +60,7 @@ Florian Ragwitz <rafl@debian.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Florian Ragwitz.
+This software is copyright (c) 2015 by Florian Ragwitz.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
